@@ -166,8 +166,22 @@ sub main {
 
     warn(Dumper($s), "\n") if $options->{debug};
 
-    # Generate the songbook.
-    my $res = $pkg->generate_songbook( $s, $options );
+    my $res;
+
+    if ( my $xc = $::config->{settings}->{transcode} ) {
+	# Set target parser for the backend so it can find the transcoded
+	# chord definitions.
+	my $p = App::Music::ChordPro::Chords::get_parser;
+	App::Music::ChordPro::Chords::set_parser($xc);
+	# Generate the songbook.
+	$res = $pkg->generate_songbook( $s, $options );
+	# Restore parser.
+	App::Music::ChordPro::Chords::set_parser($p);
+    }
+    else {
+	# Generate the songbook.
+	$res = $pkg->generate_songbook( $s, $options );
+    }
 
     # Some backends write output themselves, others return an
     # array of lines to be written.
@@ -639,6 +653,7 @@ sub app_setup {
 	  "csv!",			# Generates contents CSV
 	  "cover=s",			# Cover page(s)
 	  "filelist=s@",		# List of input files
+	  "meta=s\%",			# Command line meta data
 
           ### Standard Chordii Options ###
 
@@ -647,9 +662,9 @@ sub app_setup {
           "chord-grid-size|s=f",        # Sets chord diagram size [30]
           "chord-grids-sorted|S!",      # Prints chord diagrams ordered
           "chord-size|c=i",             # Sets chord size [9]
-	  "diagrams=s",			# Prints chords diagrams
           "dump-chords|D",              # Dumps chords definitions (PostScript)
           "dump-chords-text|d" => \$dump_chords,  # Dumps chords definitions (Text)
+          "dump-chords-json" => sub { $dump_chords = 2},  # Dumps instrument defs (json).
           "even-pages-number-left|L",   # Even pages numbers on left
           "odd-pages-number-left",      # Odd pages numbers on left
           "lyrics-only|l",              # Only prints lyrics
@@ -665,6 +680,7 @@ sub app_setup {
           "i" => sub { $clo->{toc} = 1 },
           "toc!",                       # Generates a table of contents
           "transpose|x=i",              # Transposes by N semi-tones
+          "transcode|xc=s",             # Transcodes to another notation
           "user-chord-grids!",          # Do[esn't] print diagrams for user defined chords.
           "version|V" => \$version,     # Prints version and exits
           "vertical-space|w=f",         # Extra vertical space between lines
@@ -691,9 +707,9 @@ sub app_setup {
           'help|h|?'            => \$help,
           'help-config'         => sub { $manual = 2 },
           'manual'              => \$manual,
-          'verbose|v',
+          'verbose|v+',
           'trace',
-          'debug',
+          'debug+',
 
          ) )
     {
@@ -740,8 +756,7 @@ sub app_setup {
                 foreach my $c ( @$_ ) {
 		    # Check for resource names.
 		    if ( ! -r $c && $c !~ m;[/.]; ) {
-			my $t = getresource( "config/".lc($c).".json" );
-			$c = $t if $t;
+			$c = ::rsc_or_file($c);
 		    }
                     die("$c: $!\n") unless -r $c;
                 }
@@ -759,10 +774,36 @@ sub app_setup {
         $clo->{"no$config"} = 1 unless $clo->{$config};
     }
 
+    # Decode command line strings.
+    # File names are dealt with elsewhere.
+    for ( qw(transcode) ) {
+	next unless defined $clo->{$_};
+	$clo->{$_} = decode_utf8($clo->{$_});
+    }
+
     # Plug in command-line options.
     @{$options}{keys %$clo} = values %$clo;
     # warn(Dumper($options), "\n") if $options->{debug};
 
+    if ( $clo->{transcode} ) {
+	my $xc = $clo->{transcode};
+	# Load the appropriate notes config, but retain the current parser.
+	unless ( App::Music::ChordPro::Chords::Parser->get_parser($xc, 1) ) {
+	    my $file = getresource("notes/$xc.json");
+	    if ( $file and open( my $fd, "<:raw", $file ) ) {
+		my $pp = JSON::PP->new->relaxed;
+		warn("Config: $file\n") if $clo->{verbose};
+		my $new = $pp->decode( ::loadfile ($fd, { %$clo, donotsplit => 1 } ) );
+		App::Music::ChordPro::Chords::set_notes( $new->{notes},
+							 { %$clo,
+							   'keep-parser' => 1 } );
+	    }
+	}
+	unless ( App::Music::ChordPro::Chords::Parser->get_parser($xc, 1) ) {
+	    die("No transcoder for ", $xc, "\n");
+	}
+    }
+
     if ( $defcfg || $fincfg ) {
 	print App::Music::ChordPro::Config::config_defaults()
 	  if $defcfg;
@@ -772,8 +813,9 @@ sub app_setup {
     }
 
     if ( $dump_chords ) {
+	$::config = App::Music::ChordPro::Config::configurator($options);
 	require App::Music::ChordPro::Chords;
-	App::Music::ChordPro::Chords::dump_chords();
+	App::Music::ChordPro::Chords::dump_chords($dump_chords);
 	exit 0;
     }
 
@@ -858,6 +900,7 @@ Options:
     --config=JSON  --cfg          Config definitions (multiple)
     --start-page-number=N  -p     Starting page number [1]
     --toc --notoc -i              Generates/suppresses a table of contents
+    --transcode=SYS  -xc          Transcodes to notation system
     --transpose=N  -x             Transposes by N semi-tones
     --version  -V                 Prints version and exits
 
@@ -912,6 +955,22 @@ EndOfUsage
 
 use Encode qw(decode decode_utf8 encode_utf8);
 
+sub ::rsc_or_file {
+    my ( $c ) = @_;
+    # Check for resource names.
+    if ( ! -r $c && $c !~ m;[/.]; ) {
+	my $t;
+	if ( $c =~ /^(.+):(.*)/ ) {
+	    $t = getresource( lc($1) . "/".lc($2).".json" );
+	}
+	else {
+	    $t = getresource( "config/".lc($c).".json" );
+	}
+	$c = $t if $t;
+    }
+    return $c;
+}
+
 sub ::loadfile {
     my ( $filename, $options ) = @_;
 
@@ -920,9 +979,16 @@ sub ::loadfile {
 
     # Gather data from the input.
     if ( ref($filename) ) {
-	$data = $$filename;
-	$filename = "__STRING__";
-	$encoded++;
+	if ( ref($filename) eq 'GLOB' ) {
+	    binmode( $filename, ':raw' );
+	    $data = do { local $/; <$filename> };
+	    $filename = "__GLOB__";
+	}
+	else {
+	    $data = $$filename;
+	    $filename = "__STRING__";
+	    $encoded++;
+	}
     }
     elsif ( $filename eq '-' ) {
 	$filename = "__STDIN__";
@@ -984,6 +1050,8 @@ sub ::loadfile {
 	}
     }
 
+    return $data if $options->{donotsplit};
+
     # Split in lines;
     my @lines;
     $data =~ s/^\s+//s;
@@ -1079,7 +1147,7 @@ Johan Vromans C<< <jv at CPAN dot org > >>
 =head1 SUPPORT
 
 ChordPro (the program) development is hosted on GitHub, repository
-L<https://github.com/ChrdPro/chordpro>.
+L<https://github.com/ChordPro/chordpro>.
 
 Please report any bugs or feature requests to the GitHub issue tracker,
 L<https://github.com/ChordPro/chordpro/issues>.
