@@ -16,15 +16,13 @@ sub generate_songbook {
     return [] unless eval { $sb->{songs}->[0]->{body} };
 
     # Build regex for the known metadata items.
-    if ( $::config->{metadata}->{keys} ) {
-	$re_meta = '^(' .
-	  join( '|', map { quotemeta } @{$::config->{metadata}->{keys}} )
-	    . ')$';
-	$re_meta = qr/$re_meta/;
-    }
-    else {
-	undef $re_meta;
-    }
+    $re_meta = join( '|',
+		     map { quotemeta }
+		     "title", "subtitle",
+		     "artist", "composer", "lyricist", "arranger",
+		     "album", "copyright", "year",
+		     "key", "time", "tempo", "capo", "duration" );
+    $re_meta = qr/^($re_meta)$/;
 
     my @book;
 
@@ -47,16 +45,18 @@ sub generate_song {
 
     my $tidy = $options->{'backend-option'}->{tidy};
     $lyrics_only = 2 * $::config->{settings}->{'lyrics-only'};
+    my $rechorus = $::config->{chordpro}->{chorus}->{recall};
     my $structured = ( $options->{'backend-option'}->{structure} // '' ) eq 'structured';
     # $s->structurize if ++$structured;
     my $variant = $options->{'backend-option'}->{variant} || 'cho';
+    my $seq     = $options->{'backend-option'}->{seq};
 
     my @s;
 
     if ( $s->{preamble} ) {
 	@s = @{ $s->{preamble} };
     }
- 
+
     push(@s, "{title: " . $s->{meta}->{title}->[0] . "}")
       if defined $s->{meta}->{title};
     if ( defined $s->{subtitle} ) {
@@ -64,14 +64,23 @@ sub generate_song {
     }
 
     if ( $s->{meta} ) {
+	if ( $variant eq 'msp' ) {
+	    $s->{meta}->{source} //= [ "Lead Sheet" ];
+	    $s->{meta}->{custom2} //= [ $seq ] if defined $seq;
+	}
+	# Known ones 'as is'.
 	foreach my $k ( sort keys %{ $s->{meta} } ) {
 	    next if $k =~ /^(?:title|subtitle)$/;
-	    if ( $variant eq 'msp' || $k =~ $re_meta ) {
+	    if ( $k =~ $re_meta ) {
 		push( @s, map { +"{$k: $_}" } @{ $s->{meta}->{$k} } );
+		delete $s->{meta}->{$k};
 	    }
-	    else {
-		push( @s, map { +"{meta: $k $_}" } @{ $s->{meta}->{$k} } );
-	    }
+	}
+	# Unknowns with meta prefix.
+	foreach my $k ( sort keys %{ $s->{meta} } ) {
+	    next if $k =~ /^(?:title|subtitle)$/;
+	    next if $k =~ /^_/;
+	    push( @s, map { +"{meta: $k $_}" } @{ $s->{meta}->{$k} } );
 	}
     }
 
@@ -101,7 +110,7 @@ sub generate_song {
 	    $t .= " fingers " .
 	      join(" ", map { $_ < 0 ? "N" : $_ } @{$info->{fingers}})
 		if $info->{fingers};
-	    push(@s, $t);
+	    push(@s, $t . "}");
 	}
 	push(@s, "") if $tidy;
     }
@@ -109,7 +118,7 @@ sub generate_song {
     my $ctx = "";
     my $dumphdr = 1;
 
-    if ( $s->{chords} ) {
+    if ( $s->{chords} && $variant ne 'msp' ) {
 	$dumphdr = 0 unless $s->{chords}->{origin} eq "__CLI__";
 	push( @s,
 	      @{ App::Music::ChordPro::Chords::list_chords
@@ -138,6 +147,10 @@ sub generate_song {
 			$t .= $gridparams[0];
 			$t .= "x" . $gridparams[1] if $gridparams[1];
 			$t .= "+" . $gridparams[3] if $gridparams[3];
+			if ( $gridparams[4] ) {
+			    my $tag = $gridparams[4];
+			    $t .= " " . $tag if $tag ne "";
+			}
 		    }
 		    elsif ( $elt->{name} eq "label" ) {
 			my $tag = $elt->{value};
@@ -222,9 +235,15 @@ sub generate_song {
 	    if ( $variant eq 'msp' ) {
 		push( @s, "{chorus}" );
 	    }
-	    else {
+	    elsif ( $rechorus->{quote} ) {
 		unshift( @elts, @{ $elt->{chorus} } );
 	    }
+	    elsif ( $rechorus->{type} &&  $rechorus->{tag} ) {
+		push( @s, "{".$rechorus->{type}.": ".$rechorus->{tag}."}" );
+	    }
+	    else {
+		push( @s, "{chorus}" );
+	    }
 	    next;
 	}
 
